==> homebridge-http-string-wether-0.0.12.tgz: package/index.js <==
"use strict";

var Service, Characteristic;
var temperatureService;
var request = require("request");

module.export = function (homebridge) {
	Service = homebridge.hap.Service;
	Characteristic = homebridge.hap.Characteristic;
	homebridge.registerAccessory("homebridge-http-string-wether", "Http-string-wether", WeatherAccessory);
}

function WeatherAccessory(log, config) {
	this.log = log;
	this.name = config["name"];
	this.url = config["url"];
	this.charBtemp = config["charBeforTemp"];
	this.StringLength = config["StringLength"];
	this.lastupdate = 0;
	this.temperature = 0;
}

WeatherAccessory.prototype = {

	getState: function (callback){
		if (this.lastupdate + 5 < (Date.now() /1000 | 0)){
			this.httpRequest(this.url, function (error, response, responseBody){
				if (error){
					this.log("HTTP get weather function failed: %s", error.message);
					callback(error);
				} else {
					this.log("HTTP Response", responseBody);
					var temperature = parseFloat(responseBody.substring(parseInt(this.charBtemp),parseInt(this.charBtemp) + parseInt(this.StringLength)));
					this.log("temperature: ",temperature);
					this.temperature = temperature;
					this.lastupdate = (Date.now() / 1000);
					callback(null, this.temperature);
				}
			}.bind(this));
		} else {
			this.log("Returning cached data", this.temperature);
			temperatureService.setCharacteristic(Characteristic.CurrentTempeerature, this.temperature);
			callback(null, this.temperature);
		}
	},

	identify: function (callback){
		this.log("Identify requested!");
		callback();
	},

	getServices: function (){
		var informationService = new Service.AccessoryInformation();

		informationService
			.setCharacteristic(Characteristic.Manufacturer, "Http wether")
			.setCharacteristic(Characteristic.Model, "Temp")
			.setCharacteristic(Characteristic.SerialNumber, "");

		temperatureService = new Service.TemeratureSensor(this.name);
		temperatureService
			.getCharacterisitc(Characteristic.CurrentTemperature)
			.on("get", this.getState.bind(this));

		temperatureService
			.getCharacteristic(Characteristic.CurrentTemperature)
			.setProps({minValue: -30});

		temperatureService
			.getCharacteristic(Characteristic.CurrentTemperature)
			.setProps({maxValue: 120});

		return [informationService, temperatureService];
	},

	httpRequest: function (url, callback) {
		request({
			url: url,
			body: "",
			method: "GET",
			rejectUnauthorized: false
		},
		function (error, response, body){
			callback(error, response, body)
		})
	}
	};

if (!Date.now) {
	Date.now = function () {
		return new Date().getTime();
	}
}

==> homebridge-http-string-wether-0.0.18.tgz: package/index.js <==
"use strict";

var Service, Characteristic;
var temperatureService;
var request = require('request');

module.export = function (homebridge) {
	Service = homebridge.hap.Service;
	Characteristic = homebridge.hap.Characteristic;
	homebridge.registerAccessory("homebridge-http-string-wether", "Http-string-wether", WeatherAccessory);
}

function WeatherAccessory(log, config) {
	this.log = log;
	this.name = config["name"];
	this.url = config["url"];
	this.charBtemp = config["charBeforTemp"];
	this.StringLength = config["StringLength"];
	this.lastupdate = 0;
	this.temperature = 0;
}

WeatherAccessory.prototype = {

	getState: function (callback){
		if (this.lastupdate + 5 < (Date.now() /1000 | 0)){
			request.get(this.url, function (error, response, body){
				if (!error && response.statusCode == 200){
					var termerature = body.substring(this.charBtemp,this.charBtemp + this.StringLength);
				}
			});
		} else {
			this.log("Returning cached data", this.temperature);
			temperatureService.setCharacteristic(Characteristic.CurrentTempeerature, this.temperature);
			callback(null, this.temperature);
		}
	},

	identify: function (callback){
		this.log("Identify requested!");
		callback();
	},

	getServices: function (){
		var informationService = new Service.AccessoryInformation();

		informationService
			.setCharacteristic(Characteristic.Manufacturer, "Http wether")
			.setCharacteristic(Characteristic.Model, "Temp")
			.setCharacteristic(Characteristic.SerialNumber, "");

		temperatureService = new Service.TemeratureSensor(this.name);
		temperatureService
			.getCharacterisitc(Characteristic.CurrentTemperature)
			.on("get", this.getState.bind(this));

		temperatureService
			.getCharacteristic(Characteristic.CurrentTemperature)
			.setProps({minValue: -30});

		temperatureService
			.getCharacteristic(Characteristic.CurrentTemperature)
			.setProps({maxValue: 120});

		return [informationService, temperatureService];
	},

	};

if (!Date.now) {
	Date.now = function () {
		return new Date().getTime();
	}
}
